#[logger]Expand description
Provides for logging within the attributed function/method.
This is required to be able to use the macros.
It sets up the local variable used by the other macros, and it also registers the function/method
name used by the log entries (if included in the formatter’s fmt_string).
#[logger]
pub fn my_func(msg: &str){
entering!();
fine!("msg: {msg}");
...
}